---
name: Bug report
about: Create a report to help us improve

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Data processed
2. Expected data
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
Output of `python -m TheengsGateway.diagnose` or `python -m TheengsGateway.diagnose -c path_to_conf_file` if not using the default path for the configuration file.

**Additional context**
Add any other relevant context about the problem here.
